require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xaddomaincontroller',
  dscmeta_resource_friendly_name: 'xADDomainController',
  dscmeta_resource_name: 'MSFT_xADDomainController',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '3.0.0.0',
  docs: 'The DSC xADDomainController resource type.
         Automatically generated from version 3.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_sysvolpath: {
      type: 'Optional[String]',
      desc: 'The path where the Sysvol will be stored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domainadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "The 'PSCredential' object containing Domain Administrator rights to add the Domain Controller to the domain.",
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_logpath: {
      type: 'Optional[String]',
      desc: 'The path where the logs will be stored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_databasepath: {
      type: 'Optional[String]',
      desc: 'The path where the database will be stored.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'The FQDN of the domain the Domain Controller will be joining.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_isglobalcatalog: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the domain controller will be a Global Catalog (GC).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_sitename: {
      type: 'Optional[String]',
      desc: 'The name of the site this Domain Controller will be added to.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_installationmediapath: {
      type: 'Optional[String]',
      desc: 'The path of the media you want to use install the Domain Controller.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_safemodeadministratorpassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "The 'PSCredential' object containing the password to use for DSRM.",
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: 'Optional[String]',
      desc: 'The state of the Domain Controller.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
