require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xadrecyclebin',
  dscmeta_resource_friendly_name: 'xADRecycleBin',
  dscmeta_resource_name: 'MSFT_xADRecycleBin',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '3.0.0.0',
  docs: 'The DSC xADRecycleBin resource type.
         Automatically generated from version 3.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_forestfqdn: {
      type: 'String',
      desc: 'The FQDN of the forest in which to change the Recycle Bin feature.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forestmode: {
      type: 'Optional[String]',
      desc: 'The functional level of the forest.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_recyclebinenabled: {
      type: 'Optional[String]',
      desc: 'The state of the Recycle Bin feature.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enterpriseadministratorcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The user account credentials to use to perform this task.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
