require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xadreplicationsitelink',
  dscmeta_resource_friendly_name: 'xADReplicationSiteLink',
  dscmeta_resource_name: 'MSFT_xADReplicationSiteLink',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '3.0.0.0',
  docs: 'The DSC xADReplicationSiteLink resource type.
         Automatically generated from version 3.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_sitesincluded: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the list of sites included in the site link',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies if the site link is created or deleted',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_cost: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Specifies the cost to be placed on the site link',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'This parameter sets the value of the Description property for the object',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the site link',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sitesexcluded: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the list of sites to exclude from the site link',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_replicationfrequencyinminutes: {
      type: 'Optional[Integer[-2147483648, 2147483647]]',
      desc: 'Species the frequency (in minutes) for which replication will occur where this site link is in use between sites',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'SInt32',
      mof_is_embedded: false,
    },
  },
)
