require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xwaitforaddomain',
  dscmeta_resource_friendly_name: 'xWaitForADDomain',
  dscmeta_resource_name: 'MSFT_xWaitForADDomain',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xActiveDirectory',
  dscmeta_module_version: '3.0.0.0',
  docs: 'The DSC xWaitForADDomain resource type.
         Automatically generated from version 3.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_rebootretrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The number of times to reboot after failing and then restart retrying.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_domainusercredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'The user account credentials to use to perform this task.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_retrycount: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'The number of retries before failing.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'The name of the AD Domain to wait for.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_retryintervalsec: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'The interval in seconds between retry attempts.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
  },
)
